@@ -1,27 +1,29 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cookie
-version: 0.4.1.6
-id: cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
-key: cooki_2Eb4iZo39x3Ihl7jVKbtZO
+version: 0.4.2
+id: cookie-0.4.2-28e8510d867302127f61174b072159ee
+key: cooki_HgYmE0LnTLQI3ZHrNmxIUf
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
 homepage: http://github.com/snoyberg/cookie
 synopsis: HTTP cookie parsing and rendering
+description:
+    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
 category: Web, Yesod
 author: Michael Snoyman <michael@snoyman.com>
 exposed: True
 exposed-modules:
     Web.Cookie
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.1.6
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.1.6
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cookie-0.4.1.6
-hs-libraries: HScookie-0.4.1.6-2Eb4iZo39x3Ihl7jVKbtZO
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cookie-0.4.2
+hs-libraries: HScookie-0.4.2-HgYmE0LnTLQI3ZHrNmxIUf
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
